# cython: language_level=3
import numpy as np
cimport numpy as np
from libc.stddef cimport size_t

cdef extern from "itrigamma.h":
    void itrigamma_vec(const double *y, double *out, size_t n)

def itrigamma(y):
    cdef np.ndarray[np.float64_t, ndim=1, mode="c"] y1
    cdef np.ndarray[np.float64_t, ndim=1, mode="c"] out1
    cdef size_t n
    cdef tuple shape

    arr = np.asarray(y, dtype=np.float64)
    shape = arr.shape
    y1 = np.ascontiguousarray(arr.ravel(), dtype=np.float64)
    out1 = np.empty_like(y1)

    n = <size_t> y1.size
    itrigamma_vec(<const double*> y1.data, <double*> out1.data, n)

    out = out1.reshape(shape)
    # for scalars
    if shape == ():
        return float(out[()])
    return out



import sys
from setuptools import Extension, setup
from Cython.Build import cythonize
import numpy as np


extensions = [
    Extension(
        name="itrigamma.citrigamma",
        sources=[
            "python/citrigamma.pyx",
            "src/itrigamma.c",
        ],
        include_dirs=[
            np.get_include(),
            "src",
        ],
        language="c",
        define_macros=[("NPY_NO_DEPRECATED_API", "NPY_1_7_API_VERSION")],
        extra_compile_args=["-O3"],
    )
]

setup(
    ext_modules=cythonize(
        extensions,
        compiler_directives={"language_level": "3"},
    ),
)
